| fair-software.eu recommendations | |
| :-- | :--  |
| (1/5) code repository              | [![github repo badge](https://img.shields.io/badge/github-repo-000.svg?logo=github&labelColor=gray&color=blue)](https://github.com/DroneML/segmentmytif) |
| (2/5) license                      | [![github license badge](https://img.shields.io/github/license/DroneML/segmentmytif)](https://github.com/DroneML/segmentmytif) |
| (3/5) community registry           | [![RSD](https://img.shields.io/badge/rsd-segmentmytif-00a3e3.svg)](https://www.research-software.nl/software/segmentmytif) [![workflow pypi badge](https://img.shields.io/pypi/v/segmentmytif.svg?colorB=blue)](https://pypi.python.org/project/segmentmytif/) |
| (4/5) citation                     | [![DOI](https://zenodo.org/badge/DOI/<replace-with-created-DOI>.svg)](https://doi.org/<replace-with-created-DOI>)|
| (5/5) checklist                    | [![workflow cii badge](https://bestpractices.coreinfrastructure.org/projects/<replace-with-created-project-identifier>/badge)](https://bestpractices.coreinfrastructure.org/projects/<replace-with-created-project-identifier>) |
| howfairis                          | [![fair-software badge](https://img.shields.io/badge/fair--software.eu-%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8B-yellow)](https://fair-software.eu) |